<?php

namespace App\Http\Controllers\Api\Client;

use App\Http\Controllers\Controller;
use App\Http\Resources\SalonResource;
use App\Models\Favourite;
use App\Models\Order;
use App\Models\Salon;
use App\Models\SalonComment;
use Illuminate\Http\Request;
use JWTAuth;

class FavouritesController extends Controller
{
    public function favourite_salon($id)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong_token'), 'code' => 401]);
        }
        $check = Favourite::where('user_id', $user->id)->where('salon_id', $id)->first();
        if ($check) {
            $check->delete();
            return response()->json(['value' => true, 'data' => 'تم الحذف من المفضلة', 'code' => 200]);
        } else {
            Favourite::create([
                'user_id' => $user->id,
                'salon_id' => $id
            ]);
            return response()->json(['value' => true, 'data' => 'تم الإضافة إلي المفضلة', 'code' => 200]);

        }
    }

    public function favourites()
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong_token'), 'code' => 401]);
        }
        $rows = $user->favourite_salons()->paginate(10);
        return SalonResource::collection($rows)->additional(['value' => true, 'code' => 200]);

    }

    public function rate_order(Request $request)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'order_id' => 'required|exists:orders,id',
            'rate' => 'required',
            'comment' => 'required'
        ]);
        if ($validator->passes()) {
            $rate = new SalonComment();
            $order = Order::find($request['order_id']);
            $salon = Salon::find($order->salon_id);
            $rate['order_id'] = $request['order_id'];
            $rate['rate'] = $request['rate'];
            $rate['comment'] = $request['comment'];
            $rate['user_id'] = $user->id;
            $rate['salon_id'] = $salon->id;
            $rate->save();
            $salon->rate = $salon->total_rate;
            $salon->update();
            return  response()->json(['value'=>true,'data'=>'تم التقييم بنجاح','code'=>200]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }
    }
}
