<?php

namespace App\Http\Controllers\Api\Salon;

use App\Http\Controllers\Controller;
use App\Http\Resources\SalonAccountResource;
use App\Http\Resources\TransactionResource;
use App\Http\Resources\UserSalonResource;
use App\Models\SalonAccount;
use App\Models\SalonBankTransfer;
use Carbon\Carbon;
use Illuminate\Http\Request;
use JWTAuth;

class SalonAccountsController extends Controller
{
    public function add_account(Request $request)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'bank_name' => 'required',
            'account_name' => 'required',
            'account_number' => 'required|numeric'
        ]);
        if ($validator->passes()) {

            $account = new SalonAccount();
            $account->salon_id = $user->salon->id;
            $account->bank_name = $request->bank_name;
            $account->account_name = $request->account_name;
            $account->account_number = $request->account_number;
            $account->save();

            $rows = SalonAccount::where('salon_id', $user->salon->id)->paginate(10);
            return SalonAccountResource::collection($rows)->additional(['value' => true, 'code' => 200]);
        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
    }

    public function update_account(Request $request, $id)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'bank_name' => 'required',
            'account_name' => 'required',
            'account_number' => 'required|numeric'
        ]);
        if ($validator->passes()) {
            $account = SalonAccount::find($id);
            $account->bank_name = $request->bank_name;
            $account->account_name = $request->account_name;
            $account->account_number = $request->account_number;
            $account->update();

            $rows = SalonAccount::where('salon_id', $user->salon->id)->paginate(10);
            return SalonAccountResource::collection($rows)->additional(['value' => true, 'code' => 200]);
        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);

    }

    public function delete_account($id)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $account = SalonAccount::find($id);
        if ($user->salon->id == $account->salon_id) {
            $account->delete();
        } else {
            return response()->json(['value' => false, 'msg' => 'المستخدم ليس صاحب هذا الحساب', 'code' => 401]);
        }
        $rows = SalonAccount::where('salon_id', $user->salon->id)->paginate(10);
        return SalonAccountResource::collection($rows)->additional(['value' => true, 'code' => 200]);
    }

    public function salon_accounts()
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $rows = SalonAccount::where('salon_id', $user->salon->id)->paginate(10);
        return SalonAccountResource::collection($rows)->additional(['value' => true, 'code' => 200]);


    }

    public function transactions($flag = null)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        if ($flag == 'add') {
            $transactions = $user->salon->bank_transfers()->where(['type' => 'add', 'admin_approve' => 'accept'])->paginate(10);
        } elseif ($flag == 'receive') {
            $transactions = $user->salon->bank_transfers()->where(['type' => 'receive', 'admin_approve' => 'accept'])->paginate(10);
        } else {
            $transactions = $user->salon->bank_transfers()->where(['admin_approve' => 'accept'])->paginate(10);
        }
        return TransactionResource::collection($transactions)->additional(['value' => true, 'code' => 200]);
    }

    public function transfer_request(Request $request)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'amount' => 'required',
            'account_id' => 'required|exists:salon_accounts,id'
        ]);
        if ($validator->passes()) {
            if ($user->salon->wallet < $request->amount) {
                return response()->json(['value' => false, 'msg' => 'لا يوجد هذا المبلغ فى محفظتك', 'code' => 422]);
            }
            $account = new SalonBankTransfer();
            $account->salon_id = $user->salon->id;
            $account->amount = $request->amount;
            $account->account_id = $request->account_id;
            $account->code = rand(1111, 9999);
            $account->type = 'receive';
            $account->admin_approve = 'wait';
            $account->save();
            return response()->json(['value' => true, 'data' => 'تم ارسال الطلب', 'code' => 200]);
        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);

    }


}


